cs.mtm <- function(x, y, dt = c("dpss", "sine"), wt = c("adapt","uniform"), 
          K = 3, cl = 0.95, isc.cl = c(0.1,0.5,0.9), verbose = TRUE, 
          na.action = na.fail, demean = TRUE, series = NULL, ...)
{
  weight <- match.arg(wt)
  if(is.character(dt)) dt <- match.arg(dt)
  if(is.null(series))
    series <- c(deparse(substitute(x)),deparse(substitute(y)))
  x <- check.ts(x = x, name = series[1], na.action = na.action, demean = demean)
  y <- check.ts(x = y, name = series[2], na.action = na.action, demean = demean)
  N = length(x)
  if(any(isc.cl < 0) || any(isc.cl > 1))
    stop(sQuote("isc.cl"), " must only have values between 0 and 1")
  # Calculation of multipaper spectrum estimator
  NH <- trunc(N/2)
  SD = sd(x)
  f = c(1:NH)/N

  ct <- check.taper(dt = dt, N = N, K = K, ...)
  h <- ct$h # eigenvectors
  v <- ct$v # eigenvalues
  taper <- ct$taper # taper name
  k1 <- rep(1,K)
  nh1 <- rep(1,NH)

  wx <- mvfft(h*matrix(x,N,K))[2:(NH+1),]
  wy <- mvfft(h*matrix(y,N,K))[2:(NH+1),]
  Smtkx <- Mod(wx)^2
  Smtky <- Mod(wy)^2

  if(taper == "dpss" && weight == "adapt") {
    amtmx <- a.mtm(Smtk = Smtkx, N = N, v = v, NH = NH, K = K)
    Smtx <- amtmx$Smt; wtx <- amtmx$wt; 
    amtmy <- a.mtm(Smtk = Smtky, N = N, v = v, NH = NH, K = K)
    Smty <- amtmy$Smt; wty <- amtmy$wt;
    #wtsqx <- amtmx$wtsq; #edfx <- amtmx$edf; 
    #wtsqy <- amtmy$wtsq; #edfy <- amtmy$edf;
  }
  else {
    weight <- "uniform"
#    Smtx <- as.vector((Smtkx%*%k1)/K) #[2] Eq. 369a
#    Smty <- as.vector((Smtky%*%k1)/K) #[2] Eq. 369a
    Smtx <- apply(Smtkx, 1, mean) # Eq. (369a) from the Percival and Walden textbook
    Smty <- apply(Smtky, 1, mean)
    wtx <- matrix(1,NH,K); wty <- wtx; 
#    wtsqx <- wtx; wtsqy <- wtx
  }

  CSmtk <- sqrt(wtx*wty)*wx*Conj(wy)
#  CSmt <- (CSmtk%*%k1) / (sqrt(wtsqx%*%k1)*sqrt(wtsqy%*%k1))
  CSmt <- apply(CSmtk,1,sum)/sqrt(apply(wtx,1,sum)*apply(wty,1,sum)) # Eq. (14.1) from Thomson 1982
  AmpS <- Mod(CSmt)
  PhS <- atan2(Im(CSmt),Re(CSmt))
  Coh <- AmpS^2/(Smtx*Smty)

  #jackknife confidence intervals
  Cohjk <- matrix(0,NH,K)
  PhSjk <- matrix(0,NH,K)
  for(i in 1:K) { # following equations from Thomson & Chave 1993
    CSmtkjk <- CSmtk[,-i]%*%k1[-1] # Eq.(2.57)
    Cohjk[,i] <- abs(CSmtkjk)^2/((Smtkx[,-i]%*%k1[-1])*(Smtky[,-i]%*%k1[-1]))
    PhSjk[,i] <- CSmtkjk/abs(CSmtkjk) # Eq.(2.61)
  }
#  Qm <- apply(Q, 1, mean)
#  Qvarjk <- (Q - (Qm%*%k1))^2
#  Qvar <- apply(Qvarjk, 1, mean)*(K-1)
  sCohjk <- Cohjk; sCoh <- Coh; 
  sCohjk[Cohjk > 0.999] <- 0.999; sCoh[Coh > 0.999] <- 0.999
  Q <- atanh(sqrt(sCohjk))
  Qv <- atanh(sqrt(sCoh))
  Qvar <- apply(Q, 1, var)*(K-1)^3/K/(K-1/2) # Eq.(18) from Thomson 2007
  PhSm <- apply(PhSjk, 1, mean)
  PhSvar <- 2*(K-1)*(1-abs(PhSm))

  z <- qnorm((1+cl)/2)
  Qu <- Qv + z*sqrt(Qvar)
  Ql <- Qv - z*sqrt(Qvar)
  Ql[Ql < 0] <- 0

  Coh.ci <- matrix(0,NH,2)
  PhS.ci <- matrix(0,NH,2)
  Coh.ci[,1] = (tanh(Qu))^2
  Coh.ci[,2] = (tanh(Ql))^2
  PhS.ci[,1] = PhS + z*sqrt(PhSvar)
  PhS.ci[,2] = PhS - z*sqrt(PhSvar)

  nisc <- isc.cl
  isc <- 1 - (1-isc.cl)^(1/(K-1))
  names(isc) <- nisc

  res <- cse(frequency = f, cross.spectrum = CSmt, coherence = Coh, amplitude =
             AmpS, phase = PhS, ntaper = K, coherence.ci = Coh.ci, phase.ci =
             PhS.ci, iseries.coherence.ci = isc, series = series, method =
             "Multitaper", taper = taper, weight = weight, call = match.call())
  if(verbose) print(res)
  invisible(res)
}
