\name{cs.mtm}
\alias{cs.mtm}
\title{Multitaper Cross-Spectrum Estimator}

\description{
This function estimates the cross-spectrum of two given time series using \eqn{K} tapers [1-5]. The DPSS tapers can be used with the adaptive or simple uniform weighting [1,5]. The "sine" tapers are implemented only with the uniform weighting [4]. \code{cs.mtm} outputs spectral coherence, amplitude spectrum, and phase spectrum estimates and their standard deviations obtained using a jackknife method [2-3]. The output can be visualized using \code{plot} function which actually calls \code{plot.cse}.
}
\usage{
cs.mtm(x, y, dt = c("dpss", "sine"), wt = c("adapt", "uniform"),
       K = 3, cl = 0.95, isc.cl = c(0.1,0.5,0.9), verbose = TRUE,
       na.action = na.fail, demean = TRUE, series = NULL, ...)
}
\arguments{
\item{x}{a vector containing a uniformly sampled real valued time series.}
\item{y}{a vector containing a uniformly sampled real valued time series.}
\item{dt}{a data taper to be used. If equals to either "dpss" or "sine" then the appropriate taper will be created by a call to \code{dpss.taper} or \code{sine.taper} respectively. If of class \code{dpss.taper} or \code{sine.taper} or a matrix of size Nx\code{K} where N is the input time series length and \code{K} is the number of tapers then \code{dt} will be used directly.}
\item{wt}{a weighting to use during spectrum estimation. If \code{dt} is a "sine" taper or a NxK matrix it will be forced to use uniform weighting. In case of the "dpss" taper the adaptive weighting (see [1,5]) can also be used.}
\item{K}{a number of tapers to be used.}
\item{cl}{a confidence level used for power spectrum confidence intervals estimation.}
\item{isc.cl}{a confidence level for independent time series coherence confidence intervals estimation.}
\item{verbose}{a logical flag. If TRUE (the default), prints information while executing.}
\item{na.action}{function to be called to handle missing values.}
\item{demean}{a logical flag. If TRUE (the default), the mean value of \code{x} is set to 0.}
\item{series}{a name for the series. Default: c(deparse(substitute(x)), deparse(substitute(y))).}
\item{...}{Additional arguments passed to either \code{dpss.taper} or \code{sine.taper}, the most useful of which is \code{K}, the number of data tapers to use.}
}

\value{
An object of class \code{cse} with the following values set:
\item{frequency}{a vector of frequencies.}
\item{cross.spectrum}{a multitaper cross-spectrum estimate.}
\item{coherence}{a multitaper spectral coherence estimate.}
\item{coherence.ci}{a jackknifed spectral coherence standard deviation estimate.}
\item{amplitude}{a multitaper amplitude spectrum estimate.}
\item{phase}{a multitaper phase spectrum estimate.}
\item{phase.ci}{a jackknifed phase spectrum standard deviation estimate.}
\item{ntaper}{a number of tapers used in the spectrum estimate.}
\item{series}{a name of the time series.}
\item{taper}{a data taper used}
\item{weight}{a spectrum weighting used}
\item{method}{a type of spectrum estimation method used, in this case \code{Multitaper}.}
\item{call}{the matched call for \code{cs.mtm}.}
}
\references{ 
[1] D.J. Thomson (1982), Spectrum estimation and harmonic analysis. \emph{Proc. IEEE} \bold{70}, 1055-1096.

[2] D.J. Thomson and A. D. Chave (1991), Jackknifed error estimates for spectra, coherences, and transfer functions, in \emph{Advances in Spectrum Analysis and Array Processing}, S. Haykin, Ed. Englewood Cliffs, NJ: Prentice-Hall, vol. 1, ch. 2, pp. 58--113.

[3] F.L. Vernon et al. (1991), Coherence of seismic body waves from local events as measured by a small-aperture array, \emph{J.\ Geophys.\ Res.} \bold{96},  11981-11996.

[4] K. S. Riedel and A. Sidorenko (1995), Minimum bias multiple taper spectral estimation, \emph{IEEE Transactions on Signal Processing} \bold{43}, 188-195.

[5] D.J. Thomson, L.J. Lanzerotti, F.L. Vernon, M.R. Lessard, and L.T.P. Smith (2007), Solar Modal Structure of the Engineering Environment, \emph{Proc. IEEE} \bold{95}, 1085-1132.
}
\seealso{\code{\link{plot.cse}}, \code{\link{dpss.taper}}, \code{\link{sine.taper}}, \code{\link{ps.mtm}}}
\examples{
library(PowerSpectrum)
Period = seq((1856-1659+1), length(CET_1659_2008))
CET_1856_2008 = CET_1659_2008[Period]
x = cs.mtm(CET_1856_2008, AMO_1856_2008)
plot(x)
}
\keyword{ts}
